==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebHeadSelectorTemplateDetailsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebHeadSelectorTemplateDetailsDescription } from "./WebHeadSelectorTemplateDetailsDescription";
/**
 * @hidden
 */
var WebHeadSelectorTemplateDetailsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebHeadSelectorTemplateDetailsDescriptionMetadata, _super);
    function WebHeadSelectorTemplateDetailsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebHeadSelectorTemplateDetailsDescriptionMetadata.b = function (a) {
        if (WebHeadSelectorTemplateDetailsDescriptionMetadata.a == null) {
            WebHeadSelectorTemplateDetailsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebHeadSelectorTemplateDetailsDescriptionMetadata.c(WebHeadSelectorTemplateDetailsDescriptionMetadata.a);
        }
        if (a.j(WebHeadSelectorTemplateDetailsDescriptionMetadata.a)) {
            return;
        }
        a.y(WebHeadSelectorTemplateDetailsDescriptionMetadata.a);
    };
    WebHeadSelectorTemplateDetailsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:HeadSelectorTemplateDetails");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("SelectedCount", "Number:double");
        a.item("TotalCount", "Number:double");
    };
    WebHeadSelectorTemplateDetailsDescriptionMetadata.d = function (a) {
        WebHeadSelectorTemplateDetailsDescriptionMetadata.b(a);
        a.aa("WebHeadSelectorTemplateDetails", function () { return new WebHeadSelectorTemplateDetailsDescription(); });
        a.z("WebHeadSelectorTemplateDetails", WebHeadSelectorTemplateDetailsDescriptionMetadata.a);
    };
    WebHeadSelectorTemplateDetailsDescriptionMetadata.$t = markType(WebHeadSelectorTemplateDetailsDescriptionMetadata, 'WebHeadSelectorTemplateDetailsDescriptionMetadata');
    WebHeadSelectorTemplateDetailsDescriptionMetadata.a = null;
    return WebHeadSelectorTemplateDetailsDescriptionMetadata;
}(Base));
export { WebHeadSelectorTemplateDetailsDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebHeadSelectorTemplateDetailsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebHeadSelectorTemplateDetailsDescription } from "./WebHeadSelectorTemplateDetailsDescription";
/**
 * @hidden
 */
var WebHeadSelectorTemplateDetailsDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebHeadSelectorTemplateDetailsDescriptionMetadata, _super);
    function WebHeadSelectorTemplateDetailsDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebHeadSelectorTemplateDetailsDescriptionMetadata.b = function (a) {
        if (WebHeadSelectorTemplateDetailsDescriptionMetadata.a == null) {
            WebHeadSelectorTemplateDetailsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebHeadSelectorTemplateDetailsDescriptionMetadata.c(WebHeadSelectorTemplateDetailsDescriptionMetadata.a);
        }
        if (a.k(WebHeadSelectorTemplateDetailsDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebHeadSelectorTemplateDetailsDescriptionMetadata.a);
    };
    WebHeadSelectorTemplateDetailsDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:HeadSelectorTemplateDetails");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("__skipSuffix", "Boolean");
        a.item("SelectedCount", "Number:double");
        a.item("TotalCount", "Number:double");
    };
    WebHeadSelectorTemplateDetailsDescriptionMetadata.d = function (a) {
        WebHeadSelectorTemplateDetailsDescriptionMetadata.b(a);
        a.ac("WebHeadSelectorTemplateDetails", function () { return new WebHeadSelectorTemplateDetailsDescription(); });
        a.ab("WebHeadSelectorTemplateDetails", WebHeadSelectorTemplateDetailsDescriptionMetadata.a);
    };
    WebHeadSelectorTemplateDetailsDescriptionMetadata.$t = markType(WebHeadSelectorTemplateDetailsDescriptionMetadata, 'WebHeadSelectorTemplateDetailsDescriptionMetadata');
    WebHeadSelectorTemplateDetailsDescriptionMetadata.a = null;
    return WebHeadSelectorTemplateDetailsDescriptionMetadata;
}(Base));
export { WebHeadSelectorTemplateDetailsDescriptionMetadata };
